/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.types;

import org.objectweb.fractal.adl.interfaces.Interface;

/**
 * Utility class to test {@link Interface} node.
 */
public final class TypeInterfaceUtil {

  private TypeInterfaceUtil() {
  }

  /**
   * Returns <code>true</code> if the given interface must be bound after the
   * component start. More precisely, it returns <code>true</code> if the
   * interface {@link TypeInterface#getStartProperty() startProperty} is
   * {@link TypeInterface#BINDAFTERSTART_STARTPROPERTY "bindafterstart"}.
   * 
   * @param itf an interface.
   * @return <code>true</code> if the given interface is a bindafterstart
   *         interface.
   */
  public static boolean isBindAfterStart(final Interface itf) {
    if (itf instanceof TypeInterface) {
      TypeInterface tItf = (TypeInterface) itf;
      return tItf.getStartProperty() != null
          && TypeInterface.BINDAFTERSTART_STARTPROPERTY.equals(tItf
              .getStartProperty());
    }
    return false;
  }

  /**
   * Returns <code>true</code> if the given interface is used during component
   * start. More precisely, it returns <code>true</code> if the interface
   * {@link TypeInterface#getStartProperty() startProperty} is
   * {@link TypeInterface#USED_AT_START_START_PROPERTY "usedAtStart"}.
   * 
   * @param itf an interface.
   * @return <code>true</code> if the given interface is used at start.
   */
  public static boolean isUsedAtStart(final Interface itf) {
    if (itf instanceof TypeInterface) {
      TypeInterface tItf = (TypeInterface) itf;
      return tItf.getStartProperty() != null
          && TypeInterface.USED_AT_START_START_PROPERTY.equals(tItf
              .getStartProperty());
    }
    return false;
  }
}
