/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.cecilia.adl.types;

import static org.objectweb.fractal.adl.types.TypeInterfaceUtil.isClient;
import static org.objectweb.fractal.cecilia.adl.types.TypeInterfaceUtil.isBindAfterStart;
import static org.objectweb.fractal.cecilia.adl.types.TypeInterfaceUtil.isUsedAtStart;

import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.interfaces.Interface;
import org.objectweb.fractal.adl.interfaces.InterfaceContainer;

/**
 * Extends fractal Typeloader to add checks related to Cecilia.
 * {@link TypeInterface}.
 */
public class TypeLoader extends org.objectweb.fractal.adl.types.TypeLoader {

  @Override
  protected void checkInterfaceContainer(final InterfaceContainer container,
      final Map<Object, Object> context) throws ADLException {
    // call super implementation
    super.checkInterfaceContainer(container, context);

    for (final Interface itf : container.getInterfaces()) {
      if (!(itf instanceof TypeInterface)) continue;
      final TypeInterface tItf = (TypeInterface) itf;

      // check startProperty
      if (isBindAfterStart(tItf) && !isClient(tItf)) {
        throw new ADLException("Invalid interface startProperty: \""
            + TypeInterface.BINDAFTERSTART_STARTPROPERTY
            + "\" is only applicable on client interfaces.", itf);
      }

      if (isUsedAtStart(tItf)) {
        if (!isClient(tItf)) {
          throw new ADLException("Invalid interface startProperty: \""
              + TypeInterface.USED_AT_START_START_PROPERTY
              + "\" is only applicable on client interfaces.", itf);
        }

        // Checks that the component implements a lifecycle.
        boolean ok = false;
        for (final Interface itf1 : container.getInterfaces()) {
          if (itf1.getName().equals("lifecycle-controller")) {
            ok = true;
            break;
          }
        }
        if (!ok) {
          throw new ADLException(
              "Invalid interface startProperty: \""
                  + TypeInterface.USED_AT_START_START_PROPERTY
                  + "\" is only applicable on component providing a \"lifecycle-controller\" interface.",
              itf);
        }
      }

    }
  }
}
