/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq, Ali Erdem Ozcan
 */

package org.objectweb.fractal.cecilia.adl.types;

import java.util.List;
import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.ComponentVisitor;
import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.Node;
import org.objectweb.fractal.adl.components.ComponentContainer;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.cecilia.adl.TypeNameProvider;
import org.objectweb.fractal.task.core.AbstractTaskFactoryUser;
import org.objectweb.fractal.task.core.TaskException;
import org.objectweb.fractal.task.core.primitive.annotations.ServerInterface;
import org.objectweb.fractal.task.core.primitive.annotations.ServerInterfaces;
import org.objectweb.fractal.task.core.primitive.annotations.TaskParameters;

/**
 * Creates a {@link TypeNameProvider} task for the visited component.
 */
public class TypeVisitor extends AbstractTaskFactoryUser
    implements
      ComponentVisitor {

  public Component visit(final List<Node> path, final ComponentContainer node,
      final Map<Object, Object> context) throws ADLException, TaskException {
    return taskFactoryItf.newPrimitiveTask(new TypeNameProviderImpl(
        getAbsoluteName(path, node)), node);
  }

  // ---------------------------------------------------------------------------
  // Utility methods
  // ---------------------------------------------------------------------------

  protected String getAbsoluteName(final List<Node> path,
      final ComponentContainer container) {
    String realname = getComponentName(container);
    for (int i = path.size() - 1; i >= 0; i--)
      realname = getComponentName(path.get(i)) + "/" + realname;
    return realname;
  }

  protected String getComponentName(final Node container) {
    if (container instanceof Definition)
      return ((Definition) container).getName();
    else if (container instanceof org.objectweb.fractal.adl.components.Component)
      return ((org.objectweb.fractal.adl.components.Component) container)
          .getName();
    else
      throw new IllegalArgumentException(
          "The given node is neither a Definition nor a Component");
  }

  // ---------------------------------------------------------------------------
  // Task classes
  // ---------------------------------------------------------------------------

  /**
   * Provides the name of the type of the given component.
   */
  @TaskParameters("componentNode")
  @ServerInterfaces(@ServerInterface(name = "type-name-provider", signature = TypeNameProvider.class, record = "role:typeNameProvider, id:%", parameters = "componentNode"))
  public static class TypeNameProviderImpl implements TypeNameProvider {

    protected final String typeName;
    protected final String cTypeName;

    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------

    /**
     * @param typeName the name provided by this task.
     */
    public TypeNameProviderImpl(final String typeName) {
      this.typeName = typeName;
      cTypeName = typeName.replace('.', '_').replace('-', '_')
          .replace('/', '_');
    }

    // -------------------------------------------------------------------------
    // Implementation of the TypeNameProvider interface
    // -------------------------------------------------------------------------

    public String getTypeName() {
      return typeName;
    }

    public String getCTypeName() {
      return cTypeName;
    }
  }
}
