/**
 * Cecilia, an implementation of the Fractal component model in C.
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */
#include <string.h>

#define MAGIC_NB 0xfedabc02U

struct test_bindings_BindAfterStartdata {
  unsigned int bound;
  int started, ok;
  Rtest_api_Run *c;
};

DECLARE_DATA {
  unsigned int bound;
  int started, ok;
};

#include <cecilia.h>

jint METHOD(r,run)(void *_this)
{
  if ((DATA.bound != MAGIC_NB)|| (DATA.ok == -1)) { //itf already started or not bound at all
    return -1;
  }
  return CALL(REQUIRED.c, run);
}

// -----------------------------------------------------------------------------
// Implementation of the binding-controller interface.
// -----------------------------------------------------------------------------

// int listFc(in string[] clientItfNames);
int METHOD(binding_controller, listFc)(void* _this, const char* clientItfNames[])
{
  if (clientItfNames != NULL) {
    clientItfNames[0] = "c";
  }
  return 1;
}

// int lookupFc(in string clientItfName, out any interfaceReference);
int METHOD(binding_controller, lookupFc)(void* _this, const char* clientItfName, void** interfaceReference)
{
  if (interfaceReference == NULL || clientItfName == NULL) {
    return fractal_api_ErrorConst_INVALID_ARGUMENT;
  }

  if (strcmp(clientItfName, "c") == 0) {
    *interfaceReference = REQUIRED.c;
    return fractal_api_ErrorConst_OK;
  } else {
    return fractal_api_ErrorConst_NO_SUCH_INTERFACE;
  }
}

// int bindFc(in string clientItfName, in any serverItf);
int METHOD(binding_controller, bindFc)(void* _this, const char* clientItfName, void* serverItf)
{
  if (clientItfName == NULL) {
    return fractal_api_ErrorConst_INVALID_ARGUMENT;
  }

  if (strcmp(clientItfName, "c") == 0) {
    DATA.bound = MAGIC_NB;
    REQUIRED.c = (Rtest_api_Run *) serverItf;
    return fractal_api_ErrorConst_OK;
  } else {
    return fractal_api_ErrorConst_NO_SUCH_INTERFACE;
  }
}

// int unbindFc(in string clientItfName);
int METHOD(binding_controller, unbindFc)(void* _this, const char* clientItfName)
{
  if (clientItfName == NULL) {
    return fractal_api_ErrorConst_INVALID_ARGUMENT;
  }

  if (strcmp(clientItfName, "c") == 0) {
    REQUIRED.c = NULL;
    return fractal_api_ErrorConst_OK;
  } else {
    return fractal_api_ErrorConst_NO_SUCH_INTERFACE;
  }
}

// -----------------------------------------------------------------------------
// Implementation of the lifecycle-controller interface.
// -----------------------------------------------------------------------------

// int getFcState();
int METHOD(lifecycle_controller, getFcState)(void* _this)
{
  if (DATA.started != 1)
    return fractal_api_LifeCycleController_STOPPED;
  else
    return fractal_api_LifeCycleController_STARTED;
}

// int startFc();
int METHOD(lifecycle_controller, startFc)(void* _this)
{
  if (DATA.bound == MAGIC_NB)
    //cltItf already bound, so not correct
    DATA.ok = -1;
  else
    DATA.ok = 1;

  DATA.started = 1;
  return fractal_api_ErrorConst_OK;
}

// int stopFc();
int METHOD(lifecycle_controller, stopFc)(void* _this)
{
  DATA.started = 0;
  return fractal_api_ErrorConst_OK;
}
