/**
 Copyright 2007 INRIA
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA
 
 Contact: fractal@objectweb.org
 Author:  Alessio Pace
 */
package org.objectweb.fractal.cecilia.adl.maven.plugin;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.maven.project.MavenProject;

/**
 * @author Alessio Pace
 * 
 */
public class Properties implements CeciliaAdlLauncherArguments {

	private File file;

	public String toString() {
		return "File: " + file;
	}

	public List getArguments(MavenProject project) {

		java.util.Properties p = new java.util.Properties();
		List arguments = new ArrayList(p.size());

		if (file != null) {
			try {
				final FileInputStream fileInputStream = new FileInputStream(file);
				p.load(fileInputStream);

				Set entrySet = p.entrySet();
				Iterator entriesIterator = entrySet.iterator();

				Map.Entry nameValueEntry = null;
				String name = null;
				String value = null;
				while (entriesIterator.hasNext()) {
					nameValueEntry = (Map.Entry) entriesIterator.next();
					name = (String) nameValueEntry.getKey();

					OutDirUtil.assertIsNotAnOutDirParameterName(name);

					value = (String) nameValueEntry.getValue();

					/*
					 * Replace all occurrences of ${*} by the corresponding property
					 * value
					 */
					Pattern pattern = Pattern.compile("\\$\\{[^\\$]*\\}");
					Matcher matcher = pattern.matcher(value);

					while (matcher.find()) {
						String propertyName = matcher.group();
						String key = propertyName.substring(2, propertyName
								.length() - 1);

						/*
						 * The property is searched first in the project properties,
						 * then in the system properties and finally in the
						 * environment variables
						 */
						String propertyValue = project.getProperties().getProperty(
								key);
						if (propertyValue == null) {
							propertyValue = System.getProperty(key);
							if (propertyValue == null) {
								propertyValue = System.getenv(key);
							}
						}

						if (propertyValue != null) {
							value = value.replace(propertyName, propertyValue);
							matcher.reset(value);
						}
					}

					arguments.add("-" + name + "=" + value);
				}
				return arguments;
			} catch (FileNotFoundException fnfe) {
				fnfe.printStackTrace();
			} catch (IOException ioe) {
				ioe.printStackTrace();
			}

			throw new RuntimeException("Unable to find or read properties from "
					+ file);
		}
		return arguments;

	}

}
