/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 * Base on: org.objectweb.deployment.scheduling.component.api.FactoryProviderTask 
 *          from fractal.objectweb.org
 */

package org.objectweb.fractal.task.codegen.api;

import org.objectweb.fractal.task.core.Task;

/**
 * Base interface of task providing a reference to a component factory has a
 * {@link Task#getResult() result}. In the context of dynamic deployment, the
 * component factory is a factory that can be used to instantiate a new
 * component. In the context of code generation, the result of this task is the
 * type name of the component.
 */
public interface FactoryProviderTask extends Task {

  /**
   * Return the reference of a component factory.
   * 
   * @return The reference of a component factory.
   */
  Object getFactory();

  /**
   * Set the reference of a component factory.
   * 
   * @param reference - The reference of a component factory.
   */
  void setFactory(Object reference);
}
