/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.task.codegen.api;

import java.util.Collection;

import org.objectweb.fractal.task.core.Task;
import org.objectweb.fractal.task.core.TaskMap;

/**
 * Task interface for task depending on a set of
 * {@link FileCollectionProviderTask}.
 */
public interface RequireFileCollectionProviderTask extends Task {

  /**
   * The <code>role</code> used for file collection provider task dependancy.
   * 
   * @see Task#addDependency(TaskMap.TaskHole, Class, Object)
   */
  Class<FileCollectionProviderTask> FILE_COLLECTION_PROVIDER_TASK_ROLE = FileCollectionProviderTask.class;

  /**
   * Adds a {@link FileCollectionProviderTask file collection provider task} as
   * a required task. Equivalent to
   * <code>{@link Task#addDependency(TaskMap.TaskHole, Class, Object) 
   * addDependency}(<i>task</i>, {@link #FILE_COLLECTION_PROVIDER_TASK_ROLE 
   * RequireFileCollectionProviderTask.FILE_COLLECTION_PROVIDER_TASK_ROLE},
   *  null)</code>.
   * The given task is also set as a
   * {@link Task#PREVIOUS_TASK_ROLE previous task}.
   * 
   * @param task the task to add.
   */
  void addFileCollectionProviderTask(TaskMap.TaskHole task);

  /**
   * Removes a previously added {@link FileProviderTask file provider task}.
   * Equivalent to <code>{@link Task#removeDependency(TaskMap.TaskHole, Class) 
   * removeDependency}(<i>task</i>, {@link #FILE_COLLECTION_PROVIDER_TASK_ROLE 
   * RequireFileCollectionProviderTask.FILE_COLLECTION_PROVIDER_TASK_ROLE})</code>.
   * 
   * @param task the task to remove.
   */
  void removeFileCollectionProviderTask(TaskMap.TaskHole task);

  /**
   * Returns the
   * {@link FileCollectionProviderTask file collection provider tasks} required
   * by this task.
   * 
   * @return a collection of
   *         {@link FileCollectionProviderTask file collection provider tasks}.
   */
  Collection<FileCollectionProviderTask> getFileCollectionProviderTasks();

}
