/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 * Base on: org.objectweb.deployment.scheduling.component.api.RequireFactoryProviderTask 
 *          from fractal.objectweb.org
 */

package org.objectweb.fractal.task.codegen.api;

import org.objectweb.fractal.task.core.Task;
import org.objectweb.fractal.task.core.TaskMap;

/**
 * Base interface of task depending on a
 * {@link InstanceProviderTask component instance provider task}.
 */
public interface RequireInstanceProviderTask extends Task {

  /**
   * The <code>role</code> used for instance provider task dependency.
   * 
   * @see Task#addDependency(TaskMap.TaskHole, Class, Object)
   */
  Class<?> INSTANCE_PROVIDER_TASK_ROLE = InstanceProviderTask.class;

  /**
   * Return the component instance provider task.
   * 
   * @return The component instance provider task.
   */
  InstanceProviderTask getInstanceProviderTask();

  /**
   * Set the component instance provider task. Equivalent to
   * <code>{@link Task#addDependency(TaskMap.TaskHole, Class, Object) 
   * addDependency}(<i>task</i>, {@link #INSTANCE_PROVIDER_TASK_ROLE 
   * RequireInstanceProviderTask.INSTANCE_PROVIDER_TASK_ROLE}, null)</code>.
   * The given task is also set as a
   * {@link Task#PREVIOUS_TASK_ROLE previous task}.
   * 
   * @param task - The component instance provider task.
   */
  void setInstanceProviderTask(TaskMap.TaskHole task);
}
