/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.task.codegen.api;

import org.objectweb.fractal.task.core.Task;
import org.objectweb.fractal.task.core.TaskMap;

/**
 * Task interface for task depending on a set of {@link SourceCodeProviderTask}.
 */
public interface RequireSourceCodeProviderTask extends Task {

  /**
   * The <code>role</code> used for source code provider task dependency.
   * 
   * @see Task#addDependency(TaskMap.TaskHole, Class, Object)
   */
  Class<?> SOURCE_CODE_PROVIDER_TASK_ROLE = SourceCodeProviderTask.class;

  /**
   * Adds a {@link SourceCodeProviderTask source code provider task} as a
   * required task. Equivalent to
   * <code>{@link Task#addDependency(TaskMap.TaskHole, Class, Object) 
   * addDependency}(<i>task</i>, {@link #SOURCE_CODE_PROVIDER_TASK_ROLE 
   * RequireSourceCodeProviderTask.SOURCE_CODE_PROVIDER_TASK_ROLE}, 
   * <i>codeProviderName</i>)</code>.
   * The given task is also set as a
   * {@link Task#PREVIOUS_TASK_ROLE previous task}.
   * 
   * @param codeProviderName the name associated with the added task.
   * @param task the task to add.
   */
  void addSourceCodeProviderTask(String codeProviderName, TaskMap.TaskHole task);

  /**
   * Removes a previously added
   * {@link SourceCodeProviderTask source code provider task}. Equivalent to
   * <code>{@link Task#removeDependency(TaskMap.TaskHole, Class) 
   * removeDependency}(<i>task</i>, {@link #SOURCE_CODE_PROVIDER_TASK_ROLE 
   * RequireSourceCodeProviderTask.SOURCE_CODE_PROVIDER_TASK_ROLE})</code>.
   * 
   * @param codeProviderName the name of the task to remove.
   */
  void removeSourceCodeProviderTask(String codeProviderName);

  /**
   * Returns an array containing the names of the
   * {@link SourceCodeProviderTask source code provider task} required by this
   * task.
   * 
   * @return an array containing the names of the
   *         {@link SourceCodeProviderTask source code provider task} required
   *         by this task.
   */
  String[] getSourceCodeProviderTaskNames();

  /**
   * Returns a previously added
   * {@link SourceCodeProviderTask source code provider task}.
   * 
   * @param codeProviderName the name of the task to return.
   * @return the {@link SourceCodeProviderTask source code provider task}
   *         associated with the given name.
   */
  SourceCodeProviderTask getSourceCodeProviderTask(String codeProviderName);
}
