/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.task.codegen.api;

import org.objectweb.fractal.task.core.Task;
import org.objectweb.fractal.task.core.TaskMap;

/**
 * TODO add comments for RequireSourceFileProviderTask.
 */
public interface RequireSourceFileProviderTask extends Task {

  /**
   * The <code>role</code> used for source file provider task dependency.
   * 
   * @see Task#addDependency(TaskMap.TaskHole, Class, Object)
   */
  Class<?> SOURCE_FILE_PROVIDER_TASK_ROLE = SourceFileProviderTask.class;

  /**
   * Return the source file provider task this task depends on.
   * 
   * @return The source file provider task.
   */
  SourceFileProviderTask getSourceFileProviderTask();

  /**
   * Set the source file provider task. Equivalent to
   * <code>{@link Task#addDependency(TaskMap.TaskHole, Class, Object) 
   * addDependency}(<i>task</i>, {@link #SOURCE_FILE_PROVIDER_TASK_ROLE 
   * RequireSourceFileProviderTask.SOURCE_FILE_PROVIDER_TASK_ROLE}, null)</code>.
   * The given task is also set as a
   * {@link Task#PREVIOUS_TASK_ROLE previous task}.
   * 
   * @param task - The source file provider task.
   */
  void setSourceFileProviderTask(TaskMap.TaskHole task);
}
