/***
 * Fractal Task Codegen Framework
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author: Matthieu Leclercq
 */

package org.objectweb.fractal.task.codegen.lib;

import java.util.Map;

import org.objectweb.fractal.task.codegen.util.CodeWriter;

/**
 * Aggregates the source code of its providers according to the alphabetical
 * order of their names.
 */
public class SourceCodeAggregatorTask
    extends
      AbstractRecursiveSourceCodeProviderTask {

  private final String taskName;

  /**
   * @param taskName
   */
  public SourceCodeAggregatorTask(final String taskName) {
    this(taskName, NATURAL_KEY_ORDER);
  }

  /**
   * @param taskName
   * @param order
   */
  public SourceCodeAggregatorTask(final String taskName, final int order) {
    super(order);
    this.taskName = taskName;
  }

  // --------------------------------------------------------------------------
  // Implementation of the Task interface
  // --------------------------------------------------------------------------

  public void execute(final Map<Object, Object> context) throws Exception {
    final CodeWriter cw = new CodeWriter(taskName);
    for (final Object codePiece : getCodePieces().values()) {
      cw.append(codePiece.toString());
    }
    setResult(cw.toString());
  }

}
